slepc-3.18.0 2022-10-01
Report Typos and Errors

# STCheckNullSpace

Tests if constraint vectors are nullspace vectors.

### Synopsis

    #include "slepcst.h"
    PetscErrorCode STCheckNullSpace(ST st,BV V)

Collective on st

### Input Parameters

| st | - the spectral transformation context
| V | - basis vectors to be checked

### Notes

Given a basis vectors object, this function tests each of its constraint vectors to be a nullspace vector of the coefficient matrix of the associated KSP object. All these nullspace vectors are passed to the KSP object.

This function allows handling singular pencils and solving some problems in which the nullspace is important (see the users guide for details).

### See Also

EPSSetDeflationSpace()

### Level

developer

### Location

src/sys/classes/st/interface/stsles.c
Index of all ST routines
Table of Contents for all manual pages
Index of all manual pages